/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { createStore } from 'zustand/vanilla';
import { useStore } from 'zustand';
export const cellStore = createStore((set, get) => ({
    cells: new Map(),
    source: '',
    outputsCount: 0,
    kernelAvailable: false,
    adapter: undefined,
    setCells: (cells) => set((cell) => ({ cells })),
    setSource: (id, source) => {
        const cells = get().cells;
        const cell = cells.get(id);
        if (cell) {
            cell.source = source;
        }
        else {
            cells.set(id, { source });
        }
        set((cell) => ({ cells }));
    },
    setOutputsCount: (id, outputsCount) => {
        const cells = get().cells;
        const cell = cells.get(id);
        if (cell) {
            cell.outputsCount = outputsCount;
        }
        else {
            cells.set(id, { outputsCount });
        }
        set((state) => ({ cells }));
    },
    setKernelAvailable: (kernelAvailable) => set((state) => ({ kernelAvailable })),
    setAdapter: (id, adapter) => {
        const cells = get().cells;
        const cell = cells.get(id);
        if (cell) {
            cell.adapter = adapter;
        }
        else {
            cells.set(id, { adapter });
        }
        set((cell) => ({ cells }));
    },
    getAdapter: (id) => {
        return get().cells.get(id)?.adapter;
    },
    getSource: (id) => {
        return get().cells.get(id)?.source;
    },
    getOutputsCount: (id) => {
        return get().cells.get(id)?.outputsCount;
    },
    execute: (id) => {
        const cells = get().cells;
        const cell = cells.get(id);
        if (cell) {
            cell.adapter?.execute();
        }
        else {
            get().cells.forEach((cell) => cell.adapter?.execute());
        }
    },
}));
export function useCellStore(selector) {
    return useStore(cellStore, selector);
}
export default useCellStore;
//# sourceMappingURL=CellState.js.map