import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { useState, useRef, useEffect } from 'react';
import { basicSetup } from 'codemirror';
import { EditorState, Compartment } from '@codemirror/state';
import { keymap, EditorView } from '@codemirror/view';
import { python } from '@codemirror/lang-python';
import codeMirrorTheme from './CodeMirrorTheme';
import CodeMirrorOutputToolbar from './CodeMirrorOutputToolbar';
import useOutputStore from '../output/OutputState';
export const CodeMirrorEditor = (props) => {
    const { code, codePre, outputAdapter, autoRun, disableRun, sourceId, toolbarPosition, insertText, kernel, } = props;
    const outputStore = useOutputStore();
    const [view, setView] = useState();
    const dataset = outputStore.getDataset(sourceId);
    const source = outputStore.getSource(sourceId);
    const editorDiv = useRef();
    const setEditorSource = (source) => {
        if (view && source) {
            view.dispatch({
                changes: {
                    from: 0,
                    to: view.state.doc.length,
                    insert: source,
                },
            });
        }
    };
    const doInsertText = (payload) => {
        if (view && insertText) {
            view.dispatch({
                changes: {
                    from: 0,
                    insert: insertText(payload),
                },
            });
        }
    };
    const executeCode = (editorView, code) => {
        if (disableRun) {
            alert('Code execution is disabled for this editor. There should be a button on the page to run this editor.');
            return true;
        }
        if (code) {
            outputAdapter.execute(code);
        }
        else {
            outputAdapter.execute(editorView.state.doc.toString());
        }
        return true;
    };
    useEffect(() => {
        outputStore.setSource({
            sourceId,
            source: code,
        });
        const language = new Compartment();
        const keyBinding = [
            {
                key: 'Shift-Enter',
                run: () => executeCode(editorView),
                preventDefault: true,
            },
        ];
        const state = EditorState.create({
            doc: code,
            extensions: [
                basicSetup,
                language.of(python()),
                EditorView.lineWrapping,
                keymap.of([...keyBinding]),
                codeMirrorTheme,
                EditorView.updateListener.of((viewUpdate) => {
                    if (viewUpdate.docChanged) {
                        const source = viewUpdate.state.doc.toString();
                        outputStore.setSource({
                            sourceId,
                            source,
                        });
                    }
                }),
            ],
        });
        const editorView = new EditorView({
            state: state,
            parent: editorDiv.current,
        });
        setView(editorView);
        if (autoRun) {
            executeCode(editorView);
        }
        return () => {
            editorView.destroy();
        };
    }, [code]);
    useEffect(() => {
        doInsertText(dataset?.dataset);
    }, [dataset]);
    useEffect(() => {
        setEditorSource(source?.source);
    }, [source]);
    return (_jsxs(_Fragment, { children: [kernel && toolbarPosition === 'up' && (_jsx(CodeMirrorOutputToolbar, { editorView: view, codePre: codePre, kernel: kernel, outputAdapter: outputAdapter, executeCode: executeCode })), _jsx("div", { ref: editorDiv }), kernel && toolbarPosition === 'middle' && (_jsx(CodeMirrorOutputToolbar, { editorView: view, codePre: codePre, kernel: kernel, outputAdapter: outputAdapter, executeCode: executeCode }))] }));
};
export default CodeMirrorEditor;
//# sourceMappingURL=CodeMirrorEditor.js.map