import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { createRoot } from 'react-dom/client';
import { Box, Button } from '@primer/react';
import Jupyter from '../jupyter/Jupyter';
import { useJupyter } from '../jupyter/JupyterContext';
import { Kernel } from '../jupyter/kernel/Kernel';
import Notebook from '../components/notebook/Notebook';
import CellSidebar from '../components/notebook/cell/sidebar/CellSidebar';
import useNotebookStore from '../components/notebook/NotebookState';
const NOTEBOOK_UID = 'notebook-kernel-id';
const NEW_KERNEL_NAME = 'deno';
const NotebookKernelChange = () => {
    const { kernelManager, serviceManager } = useJupyter();
    const notebookStore = useNotebookStore();
    const changeKernel = () => {
        if (kernelManager && serviceManager) {
            const kernel = new Kernel({
                kernelManager,
                kernelName: NEW_KERNEL_NAME,
                kernelSpecName: NEW_KERNEL_NAME,
                kernelType: 'notebook',
                kernelspecsManager: serviceManager.kernelspecs,
                sessionManager: serviceManager.sessions,
            });
            kernel.ready.then(() => {
                notebookStore.changeKernel({ uid: NOTEBOOK_UID, kernel });
                alert(`The kernel is changed (was python3, now ${NEW_KERNEL_NAME}). Bummer, all your variables are lost!`);
            });
        }
    };
    return (_jsxs(_Fragment, { children: [_jsx(Box, { display: "flex", children: _jsx(Button, { variant: "default", size: "small", onClick: changeKernel, children: "Assign a new Kernel" }) }), _jsx(Notebook, { path: "test.ipynb", height: "500px", uid: NOTEBOOK_UID, CellSidebar: CellSidebar })] }));
};
const div = document.createElement('div');
document.body.appendChild(div);
const root = createRoot(div);
root.render(_jsx(Jupyter, { defaultKernelName: "python", children: _jsx(NotebookKernelChange, {}) }));
//# sourceMappingURL=NotebookKernelChange.js.map