import { jsxs as _jsxs } from "react/jsx-runtime";
/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { ServerConnection, } from '@jupyterlab/services';
import { createContext, useContext } from 'react';
import { getJupyterToken } from './JupyterConfig';
import { requestAPI } from './JupyterHandlers';
import { useJupyterStoreFromContext } from '../state';
/**
 * The instance for the Jupyter context.
 */
export const JupyterContext = createContext(undefined);
export const useJupyter = (props) => {
    const context = useContext(JupyterContext);
    if (context) {
        return context;
    }
    const { kernel, kernelIsLoading, serviceManager } = useJupyterStoreFromContext(props ?? {});
    const contextFromStore = {
        collaborative: false,
        defaultKernel: kernel,
        defaultKernelIsLoading: kernelIsLoading,
        kernelManager: serviceManager?.kernels,
        lite: false,
        serverSettings: serviceManager?.serverSettings,
        serviceManager: serviceManager,
        baseUrl: '',
        wsUrl: '',
    };
    return contextFromStore;
};
/**
 * The type for the Jupyter context consumer.
 */
export const JupyterContextConsumer = JupyterContext.Consumer;
/**
 * The type for the Jupyter context provider.
 */
const JupyterProvider = JupyterContext.Provider;
/**
 * Utility method to ensure the Jupyter context is authenticated
 * with the Jupyter server.
 */
export const ensureJupyterAuth = async (serverSettings) => {
    try {
        await requestAPI(serverSettings, 'api', '');
        return true;
    }
    catch (reason) {
        console.log('The Jupyter Server API has failed with reason', reason);
        return false;
    }
};
export const createServerSettings = (baseUrl, wsUrl) => {
    return ServerConnection.makeSettings({
        baseUrl,
        wsUrl,
        token: getJupyterToken(),
        appendToken: true,
        init: {
            mode: 'cors',
            credentials: 'include',
            cache: 'no-store',
        },
    });
};
/**
 * The Jupyter context provider.
 */
export const JupyterContextProvider = props => {
    const { collaborative, lite, skeleton, children } = props;
    const { serviceManager, kernel, kernelIsLoading, } = useJupyterStoreFromContext(props);
    return (_jsxs(JupyterProvider, { value: {
            // FIXME we should not expose sub attributes
            // to promote single source of truth (like URLs come from serverSettings)
            baseUrl: serviceManager?.serverSettings.baseUrl ?? '',
            collaborative,
            defaultKernel: kernel,
            defaultKernelIsLoading: kernelIsLoading,
            kernelManager: serviceManager?.kernels,
            lite: lite,
            serverSettings: serviceManager?.serverSettings ?? createServerSettings('', ''),
            serviceManager,
            wsUrl: serviceManager?.serverSettings.wsUrl ?? '',
        }, children: [kernelIsLoading && skeleton, children] }));
};
//# sourceMappingURL=JupyterContext.js.map